@@ -9,11 +9,13 @@ namespace {
 
 const char ABORT_MESSAGE[] = "got SIGABRT.\n";
 
+#pragma GCC diagnostic ignored "-Wunused-result"
 void handle_abort [[noreturn]] (int) {
     ::write(STDERR_FILENO, ABORT_MESSAGE, sizeof(ABORT_MESSAGE) - 1);
     cybozu::dump_stack();
     std::abort();
 }
+#pragma GCC diagnostic pop
 
 } // anonymous namespace
 
