@@ -160,7 +160,10 @@ void tcp_socket::free_buffers() {
 }
 
 bool tcp_socket::_send(const char* p, std::size_t len, lock_guard& g) {
-    while( ! can_send(len) ) m_cond_write.wait(g);
+    while( ! can_send(len) ) {
+        on_buffer_full();
+        m_cond_write.wait(g);
+    }
     if( m_shutdown ) return false;
 
     if( m_pending.empty() ) {
@@ -228,7 +231,10 @@ bool tcp_socket::_sendv(const iovec* iov, const int iovcnt, lock_guard& g) {
         total += iov[i].len;
     }
 
-    while( ! can_send(total) ) m_cond_write.wait(g);
+    while( ! can_send(total) ) {
+        on_buffer_full();
+        m_cond_write.wait(g);
+    }
     if( m_shutdown ) return false;
 
     ::iovec v[MAX_IOVCNT];
@@ -393,6 +399,7 @@ int setup_server_socket(const char* bind_addr, std::uint16_t port) {
     hint.ai_flags = AI_PASSIVE | AI_NUMERICSERV;
     int e = getaddrinfo(bind_addr, s_port.c_str(), &hint, &res);
     if( e == EAI_FAMILY || e == EAI_ADDRFAMILY || e == EAI_NODATA ) {
+      IPV4:
         logger::info() << "Binding to IPv6 fails, trying IPv4...";
         hint.ai_family = AF_INET;
         e = getaddrinfo(bind_addr, s_port.c_str(), &hint, &res);
@@ -409,6 +416,12 @@ int setup_server_socket(const char* bind_addr, std::uint16_t port) {
                      res->ai_protocol);
     if( s == -1 ) {
         freeaddrinfo(res);
+
+        // getaddrinfo may return IPv6 though the kernel disables IPv6.
+        // The following is the workaround for it.
+        if( hint.ai_family == AF_INET6 && errno == EAFNOSUPPORT )
+            goto IPV4;
+
         throw_unix_error(errno, "socket");
     }
 
