@@ -22,10 +22,12 @@ const char BUCKETS[] = "buckets";
 const char MAX_DATA_SIZE[] = "max_data_size";
 const char HEAP_DATA_LIMIT[] = "heap_data_limit";
 const char MEMORY_LIMIT[] = "memory_limit";
+const char REPL_BUFSIZE[] = "repl_buffer_size";
 const char SECURE_ERASE[] = "secure_erase";
 const char LOCK_MEMORY[] = "lock_memory";
 const char WORKERS[] = "workers";
 const char GC_INTERVAL[] = "gc_interval";
+const char SLAVE_TIMEOUT[] = "slave_timeout";
 const char COUNTER_ENABLE[] = "counter.enable";
 const char COUNTER_PORT[] = "counter.port";
 const char COUNTER_MAX_CONNECTIONS[] = "counter.max_connections";
@@ -190,6 +192,13 @@ void config::load(const std::string& path) {
         m_memory_limit = parse_unit(t, MEMORY_LIMIT);
     }
 
+    if( cp.exists(REPL_BUFSIZE) ) {
+        int bufs = cp.get_as_int(REPL_BUFSIZE);
+        if( bufs < 1 )
+            throw bad_config("repl_buffer_size must be > 0");
+        m_repl_bufsize = bufs;
+    }
+
     if( cp.exists(SECURE_ERASE) ) {
         m_secure_erase = cp.get_as_bool(SECURE_ERASE);
     }
@@ -215,6 +224,13 @@ void config::load(const std::string& path) {
         m_gc_interval = n;
     }
 
+    if( cp.exists(SLAVE_TIMEOUT) ) {
+        int n = cp.get_as_int(SLAVE_TIMEOUT);
+        if( n < 1 )
+            throw bad_config("slave_timeout must be > 0");
+        m_slave_timeout = n;
+    }
+
     m_counter_config.load(cp);
 }
 
