@@ -13,6 +13,7 @@ AUTOTEST(config) {
     cybozu_assert(g_config.user() == "nobody");
     cybozu_assert(g_config.group() == "nogroup");
     cybozu_assert(g_config.memory_limit() == (1024 << 20));
+    cybozu_assert(g_config.repl_bufsize() == 100);
     cybozu_assert(g_config.secure_erase() == true);
     cybozu_assert(g_config.lock_memory() == true);
     cybozu_assert(g_config.threshold() == cybozu::severity::warning);
@@ -20,6 +21,7 @@ AUTOTEST(config) {
     cybozu_assert(g_config.heap_data_limit() == (16 << 10));
     cybozu_assert(g_config.workers() == 10);
     cybozu_assert(g_config.gc_interval() == 20);
+    cybozu_assert(g_config.slave_timeout() == 15);
     cybozu_assert(g_config.counter().enable() == true);
     cybozu_assert(g_config.counter().port() == 11216);
     cybozu_assert(g_config.counter().max_connections() == 100);
